import { Observable } from 'rxjs';
export interface RequestBodyBase {
    mediaType: string;
}
export interface FileRequestBody extends RequestBodyBase {
    type: 'file';
    fileName: string;
}
export declare const fileBody: (fileName: string, mediaType?: string) => FileRequestBody;
export interface TextRequestBody extends RequestBodyBase {
    type: 'text';
    text: string;
}
export declare const textBody: (text: string, mediaType?: string) => TextRequestBody;
export interface JsonRequestBody extends RequestBodyBase {
    type: 'json';
    value: any;
}
export declare const jsonBody: (value: any, mediaType?: string) => JsonRequestBody;
export interface BytesRequestBody extends RequestBodyBase {
    type: 'bytes';
    value: androidNative.Array<number>;
}
export declare const bytesBody: (value: androidNative.Array<number>, mediaType?: string) => BytesRequestBody;
export declare type MultiPartMediaType = 'multipart/alternative' | 'multipart/mixed' | 'multipart/digest' | 'multipart/parallel' | 'multipart/form-data';
export interface FormValuePart {
    type: 'form-value';
    name: string;
    value: string;
}
export declare const formValuePart: (name: string, value: string) => FormValuePart;
export interface FormFilePart {
    type: 'form-file';
    name: string;
    fileName: string;
    body: RequestBody;
}
export declare const formFilePart: (name: string, fileName: string, body: RequestBody) => FormFilePart;
export interface GenericPart {
    type: 'part';
    name: string;
    body: RequestBody;
    headers?: HttpRequestHeaders;
}
export declare const part: (name: string, body: RequestBody, headers?: HttpRequestHeaders) => GenericPart;
export declare type MultiPartRequestPart = FormValuePart | FormFilePart | GenericPart;
export interface MultiPartRequestBody extends RequestBodyBase {
    type: 'multipart';
    mediaType: MultiPartMediaType;
    parts: MultiPartRequestPart[];
}
export declare const multiPartBody: (parts: MultiPartRequestPart[], mediaType?: MultiPartMediaType) => MultiPartRequestBody;
export declare type RequestBody = FileRequestBody | TextRequestBody | JsonRequestBody | BytesRequestBody | MultiPartRequestBody;
export declare type HttpRequestMethod = 'GET' | 'POST';
export declare type HttpRequestHeaderValue = string | string[];
export interface HttpRequestDictionaryHeaders {
    [header: string]: HttpRequestHeaderValue;
}
export declare type HttpRequestHeaders = HttpRequestDictionaryHeaders;
export interface HttpResponseHeaders {
    [header: string]: string[];
}
export declare const loopHeaders: (headers: HttpRequestHeaders, callback: (headerName: string, headerValue: string) => void) => void;
export declare const printHeaders: (headers: HttpRequestHeaders, indentation?: string) => string;
export declare const printContentSummary: (body: RequestBody) => string;
export interface IHttpRequest {
    url: string;
    method: HttpRequestMethod;
    headers?: HttpRequestHeaders;
    content?: RequestBody;
}
export interface IHttpResponse {
    statusCode: number;
    headers: HttpResponseHeaders;
    text(): Observable<string>;
    json(): Observable<any>;
    bytes(): Observable<androidNative.Array<number>>;
    save(fileName: string): Observable<void>;
}
export interface IHttp {
    request(options: IHttpRequest): Observable<IHttpResponse>;
}
export declare type CreateHttp = (baseUrl: string, log?: (...args: (string | (() => string))[]) => void) => IHttp;
export declare function forRelativeUrl(relativeUrl: string, http: IHttp): IHttp;
export declare class HttpError extends Error {
    response?: IHttpResponse;
    constructor(message?: string);
}
export declare class TransientError extends HttpError {
    constructor(message?: string);
}
export declare const getResponseError: (statusCode: number) => TransientError | HttpError | null;
